@@ -85,11 +85,6 @@
 #'
 #' @author Jeffrey S. Evans  <jeffrey_evans@@tnc.org>
 #'
-#' @seealso \code{\link[spatialEco]{focal.lmetrics}}
-#' @seealso \code{\link[SDMTools]{ConnCompLabel}}
-#' @seealso \code{\link[SDMTools]{PatchStat}} 
-#' @seealso \code{\link[SDMTools]{ClassStat}}
-#'
 #' @examples 
 #'  library(raster)
 #'  library(sp)
@@ -109,6 +104,8 @@
 #'  # Pull metrics associated with class "0"
 #'  all.class[["0"]]
 #'
+#' @seealso \code{\link{ClassStat}}, \code{\link{connected.pixels}}, \code{\link{PatchStat}}
+#'
 #' @export 
 land.metrics <- function(x, y, bkgd = NA, metrics = c("prop.landscape"), bw = 1000, 
                          latlon = FALSE, echo = TRUE) {
@@ -117,12 +114,12 @@ land.metrics <- function(x, y, bkgd = NA, metrics = c("prop.landscape"), bw = 10
         stop("MUST BE sp SpatialPointsDataFrame OR SpatialPolygonsDataFrame CLASS OBJECT")
     if (!inherits(y, "RasterLayer")) 
         stop("MUST BE raster CLASS OBJECT")
-    mnames <- c("class", "n.patches", "total.area", "prop.landscape", "patch.density", "total.edge", "edge.density", 
-        "landscape.shape.index", "largest.patch.index", "mean.patch.area", "sd.patch.area", "min.patch.area", "max.patch.area", 
-        "perimeter.area.frac.dim", "mean.perim.area.ratio", "sd.perim.area.ratio", "min.perim.area.ratio", "max.perim.area.ratio", 
-        "mean.shape.index", "sd.shape.index", "min.shape.index", "max.shape.index", "mean.frac.dim.index", "sd.frac.dim.index", 
-        "min.frac.dim.index", "max.frac.dim.index", "total.core.area", "prop.landscape.core", "mean.patch.core.area", 
-        "sd.patch.core.area", "min.patch.core.area", "max.patch.core.area", "prop.like.adjacencies", "aggregation.index", 
+    mnames <- c("class", "n.patches", "total.area", "prop.landscape", "patch.density", "total.edge", "edge.density",
+        "landscape.shape.index", "largest.patch.index", "mean.patch.area", "sd.patch.area", "min.patch.area", "max.patch.area",
+        "perimeter.area.frac.dim", "mean.perim.area.ratio", "sd.perim.area.ratio", "min.perim.area.ratio", "max.perim.area.ratio",
+        "mean.shape.index", "sd.shape.index", "min.shape.index", "max.shape.index", "mean.frac.dim.index", "sd.frac.dim.index",
+        "min.frac.dim.index", "max.frac.dim.index", "total.core.area", "prop.landscape.core", "mean.patch.core.area",
+        "sd.patch.core.area", "min.patch.core.area", "max.patch.core.area", "prop.like.adjacencies", "aggregation.index",
         "landscape.division.index", "splitting.index", "effective.mesh.size", "patch.cohesion.index")
 			
 	  if(is.numeric(metrics)) { metrics <- mnames[metrics] }
@@ -156,7 +153,7 @@ land.metrics <- function(x, y, bkgd = NA, metrics = c("prop.landscape"), bw = 10
             fr <- raster::rasterize(lsub, cr)
             lr <- raster::mask(x = cr, mask = fr)
         }
-      LM <- SDMTools::ClassStat(lr, cellsize = raster::res(cr)[1], bkgd = bkgd, latlon = latlon)[m.idx]
+      LM <- ClassStat(lr, cellsize = raster::res(cr)[1], bkgd = bkgd, latlon = latlon)[m.idx]
         if (is.null(LM)) {
 		  LM <- as.data.frame(array(0, dim=c( length(u), length(metrics))))
 		    LM[] <- NA
